<?php
/**
 * VW Life Coach Theme Customizer
 *
 * @package VW Life Coach
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function vw_life_coach_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_life_coach_custom_controls' );

function vw_life_coach_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_life_coach_customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_life_coach_customize_partial_blogdescription',
	));

	//Homepage Settings
	$wp_customize->add_panel( 'vw_life_coach_homepage_panel', array(
		'title' => esc_html__( 'Homepage Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_panel_id',
		'priority' => 20,
	));

	//Top Header
	$wp_customize->add_section( 'vw_life_coach_top_header' , array(
    	'title' => esc_html__( 'Top Header', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_homepage_panel'
	) );

   	// Header Background color
	$wp_customize->add_setting('vw_life_coach_header_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_header_background_color', array(
		'label'    => __('Header Background Color', 'vw-life-coach'),
		'section'  => 'header_image',
	)));

	$wp_customize->add_setting('vw_life_coach_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','vw-life-coach'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-life-coach' ),
			'center top'   => esc_html__( 'Top', 'vw-life-coach' ),
			'right top'   => esc_html__( 'Top Right', 'vw-life-coach' ),
			'left center'   => esc_html__( 'Left', 'vw-life-coach' ),
			'center center'   => esc_html__( 'Center', 'vw-life-coach' ),
			'right center'   => esc_html__( 'Right', 'vw-life-coach' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-life-coach' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-life-coach' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-life-coach' ),
		),
	));

	$wp_customize->add_setting('vw_life_coach_top_bar_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_life_coach_top_bar_text',array(
		'label'	=> esc_html__('Anouncement Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Lorem ipsum dolor sit amet ipsum dolor sit amet.', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_life_coach_email_text',array(
		'label'	=> esc_html__('Email Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Mail', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));	
	$wp_customize->add_control('vw_life_coach_email_address',array(
		'label'	=> esc_html__('Email Address','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'support@email.com', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_life_coach_mail_icon',array(
		'default'	=> 'far fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new vw_life_coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_mail_icon',array(
		'label'	=> __('Add Mail Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_top_header',
		'setting'	=> 'vw_life_coach_mail_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_life_coach_phone_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_life_coach_phone_text',array(
		'label'	=> esc_html__('Phone Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Phone', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'vw_life_coach_sanitize_phone_number'
	));	
	$wp_customize->add_control('vw_life_coach_phone_number',array(
		'label'	=> esc_html__('Phone Number','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '+00 123 456 7890', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_life_coach_phone_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new vw_life_coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_phone_icon',array(
		'label'	=> __('Add Phone Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_top_header',
		'setting'	=> 'vw_life_coach_phone_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_life_coach_cosulation_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_life_coach_cosulation_btn_text',array(
		'label'	=> esc_html__('Button Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Get Free Consulation!', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_cosulation_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_life_coach_cosulation_btn_link',array(
		'label'	=> esc_html__('Button Link','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'https://www.example.com', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'url'
	));

    $wp_customize->add_setting('vw_life_coach_cosulation_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new vw_life_coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_cosulation_icon',array(
		'label'	=> __('Add Button Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_top_header',
		'setting'	=> 'vw_life_coach_cosulation_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_life_coach_doc_download_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_life_coach_doc_download_text',array(
		'label'	=> esc_html__('Docs Download Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Get Free Life Coach Magazine!', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_doc_download_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_life_coach_doc_download_link',array(
		'label'	=> esc_html__('Docs Download Link','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'https://www.example.zip', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_top_header',
		'type'=> 'url'
	));

    $wp_customize->add_setting('vw_life_coach_download_icon',array(
		'default'	=> 'fas fa-download',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new vw_life_coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_download_icon',array(
		'label'	=> __('Add Download Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_top_header',
		'setting'	=> 'vw_life_coach_download_icon',
		'type'		=> 'icon'
	)));


	//Menu Settings
	$wp_customize->add_section( 'vw_life_coach_menu_setting' , array(
    	'title' => esc_html__( 'Menu Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_homepage_panel'
	) );

	$wp_customize->add_setting('vw_life_coach_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_menu_setting',
		'type'=> 'text'
	));
	
	$wp_customize->add_setting('vw_life_coach_navigation_menu_font_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','vw-life-coach'),
        'section' => 'vw_life_coach_menu_setting',
        'choices' => array(
        	'100' => __('100','vw-life-coach'),
            '200' => __('200','vw-life-coach'),
            '300' => __('300','vw-life-coach'),
            '400' => __('400','vw-life-coach'),
            '500' => __('500','vw-life-coach'),
            '600' => __('600','vw-life-coach'),
            '700' => __('700','vw-life-coach'),
            '800' => __('800','vw-life-coach'),
            '900' => __('900','vw-life-coach'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('vw_life_coach_menu_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','vw-life-coach'),
		'choices' => array(
            'Uppercase' => __('Uppercase','vw-life-coach'),
            'Capitalize' => __('Capitalize','vw-life-coach'),
            'Lowercase' => __('Lowercase','vw-life-coach'),
        ),
		'section'=> 'vw_life_coach_menu_setting',
	));

	$wp_customize->add_setting('vw_life_coach_menus_item_style',array(
	    'default' => '',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_menus_item_style',array(
		'type' => 'select',
		'section' => 'vw_life_coach_menu_setting',
		'label' => __('Menu Item Hover Style','vw-life-coach'),
		'choices' => array(
			'None' => __('None','vw-life-coach'),
	        'Zoom In' => __('Zoom In','vw-life-coach'),
        ),
	) );

	$wp_customize->add_setting('vw_life_coach_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_header_menus_color', array(
		'label'    => __('Menus Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_menu_setting',
	)));

	$wp_customize->add_setting('vw_life_coach_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_menu_setting',
	)));

	$wp_customize->add_setting('vw_life_coach_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_menu_setting',
	)));

	$wp_customize->add_setting('vw_life_coach_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_menu_setting',
	)));

	//Social links
	$wp_customize->add_section(
		'vw_life_coach_social_links', array(
			'title'		=>	__('Social Links', 'vw-life-coach'),
			'priority'	=>	null,
			'panel'		=>	'vw_life_coach_homepage_panel'
	));

	$wp_customize->add_setting('vw_life_coach_social_icons',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_social_icons',array(
		'label' =>  __('Steps to setup social icons','vw-life-coach'),
		'description' => __('<p>1. Go to Dashboard >> Appearance >> Widgets</p>
			<p>2. Add Vw Social Icon Widget in Social Icon Widget area.</p>
			<p>3. Add social icons url and save.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_social_links',
		'type'=> 'hidden'
	));
	$wp_customize->add_setting('vw_life_coach_social_icon_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_social_icon_btn',array(
		'description' => "<a target='_blank' href='". admin_url('widgets.php') ." '>Setup Social Icons</a>",
		'section'=> 'vw_life_coach_social_links',
		'type'=> 'hidden'
	));
	    
	//Slider
	$wp_customize->add_section( 'vw_life_coach_slidersettings' , array(
    	'title' => esc_html__( 'Slider Settings', 'vw-life-coach' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/life-coach-wordpress-theme/">GET PRO</a>','vw-life-coach'),
		'panel' => 'vw_life_coach_homepage_panel'
	) );

	$wp_customize->add_setting('vw_life_coach_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	) );
	$wp_customize->add_control('vw_life_coach_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','vw-life-coach'),
        'section' => 'vw_life_coach_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','vw-life-coach'),
            'Advance slider' => __('Advance slider','vw-life-coach'),
        ),
	));

	$wp_customize->add_setting('vw_life_coach_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','vw-life-coach'),
		'section'=> 'vw_life_coach_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_life_coach_advance_slider',
	));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_life_coach_slider_arrows',array(
		'selector'        => '#slider .carousel-caption h1',
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_slider_arrows',
	));

	$wp_customize->add_setting( 'vw_life_coach_slider_arrows',array(
    	'default' => 0,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','vw-life-coach' ),
      	'section' => 'vw_life_coach_slidersettings',
      	'active_callback' => 'vw_life_coach_default_slider'
    )));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'vw_life_coach_slider_page' . $count, array(
			'default'  => '',
			'sanitize_callback' => 'vw_life_coach_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_life_coach_slider_page' . $count, array(
			'label'    => esc_html__( 'Select Slider Page', 'vw-life-coach' ),
			'description' => esc_html__('Slider image size (1400 x 550)','vw-life-coach'),
			'section'  => 'vw_life_coach_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'vw_life_coach_default_slider'
		) );
	}

	$wp_customize->add_setting( 'vw_life_coach_slider_small_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_life_coach_slider_small_title', array(
		'label'    => __( 'Add Slider Small Text', 'vw-life-coach' ),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem ipsum dolor sit amet', 'vw-life-coach' ),
        ),
		'section'  => 'vw_life_coach_slidersettings',
		'type'     => 'text',
		'active_callback' => 'vw_life_coach_default_slider'
	) );

	$wp_customize->add_setting('vw_life_coach_topbar_btn_text',array(
		'default'=> 'Get Started',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_topbar_btn_text',array(
		'label'	=> esc_html__('Add Button Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Get Started', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_slidersettings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_topbar_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('vw_life_coach_topbar_btn_link',array(
		'label'	=> esc_html__('Add Button Link','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_slidersettings',
		'type'=> 'url'
	));

	//content layout
	$wp_customize->add_setting('vw_life_coach_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Life_Coach_Image_Radio_Control($wp_customize, 'vw_life_coach_slider_content_option', array(
        'type' => 'select',
        'label' => esc_html__('Slider Content Layouts','vw-life-coach'),
        'section' => 'vw_life_coach_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ),'active_callback' => 'vw_life_coach_default_slider'
    )));

    //Slider content padding
    $wp_customize->add_setting('vw_life_coach_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','vw-life-coach'),
		'description'	=> __('Enter a value in %. Example:20%','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_life_coach_default_slider'
	));

	$wp_customize->add_setting('vw_life_coach_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','vw-life-coach'),
		'description'	=> __('Enter a value in %. Example:20%','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_life_coach_default_slider'
	));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_life_coach_slider_excerpt_number', array(
		'default'              => 25,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_life_coach_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-life-coach' ),
		'section'     => 'vw_life_coach_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_life_coach_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'vw_life_coach_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('vw_life_coach_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_slider_height',array(
		'label'	=> __('Slider Height','vw-life-coach'),
		'description'	=> __('Specify the slider height (px).','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_life_coach_default_slider'
	));

	$wp_customize->add_setting( 'vw_life_coach_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'vw_life_coach_sanitize_float'
	) );
	$wp_customize->add_control( 'vw_life_coach_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-life-coach'),
		'section' => 'vw_life_coach_slidersettings',
		'type'  => 'number',
		'active_callback' => 'vw_life_coach_default_slider'
	) );

	//Opacity
	$wp_customize->add_setting('vw_life_coach_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control( 'vw_life_coach_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-life-coach' ),
	'section'     => 'vw_life_coach_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_life_coach_slider_opacity_color',
	'choices' => array(
		'0' =>  esc_attr('0','vw-life-coach'),
		'0.1' =>  esc_attr('0.1','vw-life-coach'),
		'0.2' =>  esc_attr('0.2','vw-life-coach'),
		'0.3' =>  esc_attr('0.3','vw-life-coach'),
		'0.4' =>  esc_attr('0.4','vw-life-coach'),
		'0.5' =>  esc_attr('0.5','vw-life-coach'),
		'0.6' =>  esc_attr('0.6','vw-life-coach'),
		'0.7' =>  esc_attr('0.7','vw-life-coach'),
		'0.8' =>  esc_attr('0.8','vw-life-coach'),
		'0.9' =>  esc_attr('0.9','vw-life-coach')
	),'active_callback' => 'vw_life_coach_default_slider'
	));

	$wp_customize->add_setting( 'vw_life_coach_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_slider_image_overlay',array(
      	'label' => esc_html__( 'Show / Hide Slider Image Overlay','vw-life-coach' ),
      	'section' => 'vw_life_coach_slidersettings',
      	'active_callback' => 'vw_life_coach_default_slider'
    )));

    $wp_customize->add_setting('vw_life_coach_slider_image_overlay_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_slidersettings',
		'active_callback' => 'vw_life_coach_default_slider'
	)));

	//about us Section
	$wp_customize->add_section('vw_life_coach_about_us', array(
		'title'       => __('About Us Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_about_us_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_about_us_text',array(
		'description' => __('<p>1. More options for about us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about us section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_about_us',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_about_us_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_about_us_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_about_us',
		'type'=> 'hidden'
	));

	//portfolio Section
	$wp_customize->add_section('vw_life_coach_portfolio', array(
		'title'       => __('Portfolio Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_portfolio_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_portfolio_text',array(
		'description' => __('<p>1. More options for portfolio section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for portfolio section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_portfolio',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_portfolio_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_portfolio_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_portfolio',
		'type'=> 'hidden'
	));

	//why choose us Section
	$wp_customize->add_section('vw_life_coach_why_choose_us', array(
		'title'       => __('Why Choose Us Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_why_choose_us_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_why_choose_us_text',array(
		'description' => __('<p>1. More options for why choose us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for why choose us section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_why_choose_us',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_why_choose_us_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_why_choose_us_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_why_choose_us',
		'type'=> 'hidden'
	));

	//records Section
	$wp_customize->add_section('vw_life_coach_records', array(
		'title'       => __('Records Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_records_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_records_text',array(
		'description' => __('<p>1. More options for records section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for records section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_records',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_records_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_records_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_records',
		'type'=> 'hidden'
	));

	//feature Section
	$wp_customize->add_section('vw_life_coach_feature', array(
		'title'       => __('Feature Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_feature_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_feature_text',array(
		'description' => __('<p>1. More options for feature section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for feature section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_feature',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_feature_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_feature_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_feature',
		'type'=> 'hidden'
	));

	//testimonials Section
	$wp_customize->add_section('vw_life_coach_testimonials', array(
		'title'       => __('Testimonials Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme testimonialss</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_testimonials_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_testimonials_text',array(
		'description' => __('<p>1. More options for testimonials section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonials section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_testimonials',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_testimonials_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_testimonials_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_testimonials',
		'type'=> 'hidden'
	));
		
	//discoverMore Section
	$wp_customize->add_section('vw_life_coach_discovermore', array(
		'title'       => __('Discover More Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme discovermores</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_discovermore_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_discovermore_text',array(
		'description' => __('<p>1. More options for discover more section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for discover more section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_discovermore',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_discovermore_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_discovermore_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_discovermore',
		'type'=> 'hidden'
	));

	//Services
	$wp_customize->add_section('vw_life_coach_services',array(
		'title'	=> __('Services Section','vw-life-coach'),
		'description' => __('For more options of services section<br/><a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/life-coach-wordpress-theme/">GET PRO</a>','vw-life-coach'),
		'panel' => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_section_text',array(
		'label'	=> esc_html__('Section Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Our Exclusive Blog', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_services',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_section_title',array(
		'label'	=> esc_html__('Section Title','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Our Articles & News', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_services',
		'type'=> 'text'
	));

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';	
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_life_coach_services_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_life_coach_sanitize_choices',
	));
	$wp_customize->add_control('vw_life_coach_services_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Latest Post','vw-life-coach'),		
		'section' => 'vw_life_coach_services',
	));

	//progress enquiry Section
	$wp_customize->add_section('vw_life_coach_progress_enquiry', array(
		'title'       => __('Progress Enquiry Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme progress_enquirys</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_progress_enquiry_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_progress_enquiry_text',array(
		'description' => __('<p>1. More options for progress enquiry section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for progress enquiry section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_progress_enquiry',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_progress_enquiry_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_progress_enquiry_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_progress_enquiry',
		'type'=> 'hidden'
	));

	//pricing plan Section
	$wp_customize->add_section('vw_life_coach_pricing_plan', array(
		'title'       => __('Pricing Plan Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme pricing_plans</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_pricing_plan_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_pricing_plan_text',array(
		'description' => __('<p>1. More options for pricing plan section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for pricing plan section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_pricing_plan',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_pricing_plan_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_pricing_plan_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_pricing_plan',
		'type'=> 'hidden'
	));

	//partners Section
	$wp_customize->add_section('vw_life_coach_partners', array(
		'title'       => __('Partners Section', 'vw-life-coach'),
		'description' => __('<p class="premium-opt">Premium Theme partnerss</p>','vw-life-coach'),
		'priority'    => null,
		'panel'       => 'vw_life_coach_homepage_panel',
	));

	$wp_customize->add_setting('vw_life_coach_partners_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_partners_text',array(
		'description' => __('<p>1. More options for partners section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for partners section.</p>','vw-life-coach'),
		'section'=> 'vw_life_coach_partners',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_life_coach_partners_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_partners_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_life_coach_guide') ." '>More Info</a>",
		'section'=> 'vw_life_coach_partners',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('vw_life_coach_footer',array(
		'title'	=> esc_html__('Footer Settings','vw-life-coach'),
		'description' => __('For more options of footer section<br/><a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/life-coach-wordpress-theme/">GET PRO</a>','vw-life-coach'),
		'panel' => 'vw_life_coach_homepage_panel',
	));	

	$wp_customize->add_setting( 'vw_life_coach_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','vw-life-coach' ),
      'section' => 'vw_life_coach_footer'
    )));

 	// font size
	$wp_customize->add_setting('vw_life_coach_button_footer_font_size',array(
		'default'=> 25,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','vw-life-coach'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_life_coach_footer',
	));

	$wp_customize->add_setting('vw_life_coach_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','vw-life-coach'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'vw_life_coach_footer',
	));

	// text trasform
	$wp_customize->add_setting('vw_life_coach_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','vw-life-coach'),
		'choices' => array(
      'Uppercase' => __('Uppercase','vw-life-coach'),
      'Capitalize' => __('Capitalize','vw-life-coach'),
      'Lowercase' => __('Lowercase','vw-life-coach'),
    ),
		'section'=> 'vw_life_coach_footer',
	));

	$wp_customize->add_setting('vw_life_coach_footer_heading_weight',array(
        'default' => 700,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','vw-life-coach'),
        'section' => 'vw_life_coach_footer',
        'choices' => array(
        	'100' => __('100','vw-life-coach'),
            '200' => __('200','vw-life-coach'),
            '300' => __('300','vw-life-coach'),
            '400' => __('400','vw-life-coach'),
            '500' => __('500','vw-life-coach'),
            '600' => __('600','vw-life-coach'),
            '700' => __('700','vw-life-coach'),
            '800' => __('800','vw-life-coach'),
            '900' => __('900','vw-life-coach'),
        ),
	) );

    $wp_customize->add_setting('vw_life_coach_footer_template',array(
		'default'	=> esc_html('vw_life_coach-footer-one'),
		'sanitize_callback'	=> 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_footer_template',array(
		'label'	=> esc_html__('Footer style','vw-life-coach'),
		'section'	=> 'vw_life_coach_footer',
		'setting'	=> 'vw_life_coach_footer_template',
		'type' => 'select',
		'choices' => array(
			'vw_life_coach-footer-one' => esc_html__('Style 1', 'vw-life-coach'),
			'vw_life_coach-footer-two' => esc_html__('Style 2', 'vw-life-coach'),
			'vw_life_coach-footer-three' => esc_html__('Style 3', 'vw-life-coach'),
			'vw_life_coach-footer-four' => esc_html__('Style 4', 'vw-life-coach'),
			'vw_life_coach-footer-five' => esc_html__('Style 5', 'vw-life-coach'),
		)
	));

	$wp_customize->add_setting('vw_life_coach_footer_background_color', array(
		'default'           => '#252525',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_footer_background_color', array(
		'label'    => __('Footer Background Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_footer',
	)));

	$wp_customize->add_setting('vw_life_coach_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_life_coach_footer_background_image',array(
        'label' => __('Footer Background Image','vw-life-coach'),
        'section' => 'vw_life_coach_footer'
	)));

	$wp_customize->add_setting('vw_life_coach_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','vw-life-coach'),
		'section' => 'vw_life_coach_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-life-coach' ),
			'center top'   => esc_html__( 'Top', 'vw-life-coach' ),
			'right top'   => esc_html__( 'Top Right', 'vw-life-coach' ),
			'left center'   => esc_html__( 'Left', 'vw-life-coach' ),
			'center center'   => esc_html__( 'Center', 'vw-life-coach' ),
			'right center'   => esc_html__( 'Right', 'vw-life-coach' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-life-coach' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-life-coach' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-life-coach' ),
		),
	)); 
	
	// Footer
	$wp_customize->add_setting('vw_life_coach_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','vw-life-coach'),
		'choices' => array(
            'fixed' => __('fixed','vw-life-coach'),
            'scroll' => __('scroll','vw-life-coach'),
        ),
		'section'=> 'vw_life_coach_footer',
	));

	// footer padding
	$wp_customize->add_setting('vw_life_coach_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'vw-life-coach' ),
    ),
		'section'=> 'vw_life_coach_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','vw-life-coach'),
        'section' => 'vw_life_coach_footer',
        'choices' => array(
        	'Left' => __('Left','vw-life-coach'),
            'Center' => __('Center','vw-life-coach'),
            'Right' => __('Right','vw-life-coach')
        ),
	) );

	$wp_customize->add_setting('vw_life_coach_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','vw-life-coach'),
        'section' => 'vw_life_coach_footer',
        'choices' => array(
        	'Left' => __('Left','vw-life-coach'),
            'Center' => __('Center','vw-life-coach'),
            'Right' => __('Right','vw-life-coach')
        ),
	) );

   // footer social icon
  	$wp_customize->add_setting( 'vw_life_coach_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
  	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_footer_icon',array(
		'label' => esc_html__( 'Show / Hide Footer Social Icon','vw-life-coach' ),
		'section' => 'vw_life_coach_footer'
    )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_life_coach_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_footer_text', 
	));

	$wp_customize->add_setting( 'vw_life_coach_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','vw-life-coach' ),
      'section' => 'vw_life_coach_footer'
    )));

	$wp_customize->add_setting( 'vw_life_coach_copyright_first_color', array(
	    'default' => '#f9ce44',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
  	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vw_life_coach_copyright_first_color', array(
  		'label' => __('Copyright First Color Option', 'vw-life-coach'),
	    'section' => 'vw_life_coach_footer',
	    'settings' => 'vw_life_coach_copyright_first_color',
  	)));

  	$wp_customize->add_setting( 'vw_life_coach_copyright_second_color', array(
	    'default' => '#ea430f',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
  	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vw_life_coach_copyright_second_color', array(
  		'label' => __('Copyright Second Color Option', 'vw-life-coach'),
	    'section' => 'vw_life_coach_footer',
	    'settings' => 'vw_life_coach_copyright_second_color',
  	))); 
	
	$wp_customize->add_setting('vw_life_coach_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_life_coach_footer_text',array(
		'label'	=> esc_html__('Copyright Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2020, .....', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_copyright_alignment',array(
        'default' => 'center',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Life_Coach_Image_Radio_Control($wp_customize, 'vw_life_coach_copyright_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','vw-life-coach'),
        'section' => 'vw_life_coach_footer',
        'settings' => 'vw_life_coach_copyright_alignment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

	$wp_customize->add_setting( 'vw_life_coach_footer_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_footer_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','vw-life-coach' ),
      	'section' => 'vw_life_coach_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_life_coach_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('vw_life_coach_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_footer',
		'setting'	=> 'vw_life_coach_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_life_coach_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_scroll_to_top_width',array(
		'label'	=> __('Icon Width','vw-life-coach'),
		'description'	=> __('Enter a value in pixels Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_scroll_to_top_height',array(
		'label'	=> __('Icon Height','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_life_coach_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_life_coach_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-life-coach' ),
		'section'     => 'vw_life_coach_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    $wp_customize->add_setting('vw_life_coach_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Life_Coach_Image_Radio_Control($wp_customize, 'vw_life_coach_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','vw-life-coach'),
        'section' => 'vw_life_coach_footer',
        'settings' => 'vw_life_coach_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

	//Blog Post Settings
	$wp_customize->add_panel( 'vw_life_coach_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_life_coach_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('vw_life_coach_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
    ));
    $wp_customize->add_control(new VW_Life_Coach_Image_Radio_Control($wp_customize, 'vw_life_coach_blog_layout_option', array(
        'type' => 'select',
        'label' => esc_html__('Blog Layouts','vw-life-coach'),
        'section' => 'vw_life_coach_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	$wp_customize->add_setting('vw_life_coach_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','vw-life-coach'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','vw-life-coach'),
        'section' => 'vw_life_coach_post_settings',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','vw-life-coach'),
            'Right Sidebar' => esc_html__('Right Sidebar','vw-life-coach'),
            'One Column' => esc_html__('One Column','vw-life-coach'),
            'Three Columns' => esc_html__('Three Columns','vw-life-coach'),
            'Four Columns' => esc_html__('Four Columns','vw-life-coach'),
            'Grid Layout' => esc_html__('Grid Layout','vw-life-coach')
        ),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_life_coach_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_toggle_postdate', 
	));

	$wp_customize->add_setting('vw_life_coach_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_post_settings',
		'setting'	=> 'vw_life_coach_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_life_coach_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_toggle_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','vw-life-coach' ),
        'section' => 'vw_life_coach_post_settings'
    )));

  	$wp_customize->add_setting('vw_life_coach_toggle_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_post_settings',
		'setting'	=> 'vw_life_coach_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_life_coach_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-life-coach' ),
		'section' => 'vw_life_coach_post_settings'
    )));

  	$wp_customize->add_setting('vw_life_coach_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_post_settings',
		'setting'	=> 'vw_life_coach_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_life_coach_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-life-coach' ),
		'section' => 'vw_life_coach_post_settings'
    )));

  	$wp_customize->add_setting('vw_life_coach_toggle_time_icon',array(
	'default'	=> 'far fa-clock',
	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_post_settings',
		'setting'	=> 'vw_life_coach_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_life_coach_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','vw-life-coach' ),
		'section' => 'vw_life_coach_post_settings'
    )));

    $wp_customize->add_setting( 'vw_life_coach_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','vw-life-coach' ),
		'section' => 'vw_life_coach_post_settings'
    )));

    $wp_customize->add_setting( 'vw_life_coach_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_life_coach_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','vw-life-coach' ),
		'section'     => 'vw_life_coach_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_life_coach_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_life_coach_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','vw-life-coach' ),
		'section'     => 'vw_life_coach_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('vw_life_coach_blog_post_featured_image_dimension',array(
	   'default' => 'default',
	   'sanitize_callback'	=> 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_blog_post_featured_image_dimension',array(
	   'type' => 'select',
	   'label'	=> __('Blog Post Featured Image Dimension','vw-life-coach'),
	   'section'	=> 'vw_life_coach_post_settings',
	   'choices' => array(
	        'default' => __('Default','vw-life-coach'),
	        'custom' => __('Custom Image Size','vw-life-coach'),
	    ),
	));

	$wp_customize->add_setting('vw_life_coach_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('vw_life_coach_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'vw-life-coach' ),),
		'section'=> 'vw_life_coach_post_settings',
		'type'=> 'text',
		'active_callback' => 'vw_life_coach_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('vw_life_coach_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'vw-life-coach' ),),
		'section'=> 'vw_life_coach_post_settings',
		'type'=> 'text',
		'active_callback' => 'vw_life_coach_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting('vw_life_coach_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','vw-life-coach'),
        'section' => 'vw_life_coach_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','vw-life-coach'),
            'Without Blocks' => __('Without Blocks','vw-life-coach')
        ),
	) );

    $wp_customize->add_setting( 'vw_life_coach_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_life_coach_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-life-coach' ),
		'section'     => 'vw_life_coach_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_life_coach_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

    $wp_customize->add_setting('vw_life_coach_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','vw-life-coach'),
        'section' => 'vw_life_coach_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','vw-life-coach'),
            'Excerpt' => esc_html__('Excerpt','vw-life-coach'),
            'No Content' => esc_html__('No Content','vw-life-coach')
        ),
	) );

	$wp_customize->add_setting('vw_life_coach_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-life-coach'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-life-coach'),
		'section'=> 'vw_life_coach_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_blog_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_blog_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_life_coach_blog_pagination_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_blog_pagination_hide_show',array(
		'label' => esc_html__( 'Show / Hide Blog Pagination','vw-life-coach' ),
		'section' => 'vw_life_coach_post_settings'
    )));

	$wp_customize->add_setting( 'vw_life_coach_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'vw_life_coach_sanitize_choices'
    ));
    $wp_customize->add_control( 'vw_life_coach_blog_pagination_type', array(
        'section' => 'vw_life_coach_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'vw-life-coach' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'vw-life-coach' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'vw-life-coach' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'vw_life_coach_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_life_coach_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_button_text', 
	));

    $wp_customize->add_setting('vw_life_coach_button_text',array(
		'default'=> esc_html__('Read More','vw-life-coach'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('vw_life_coach_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_button_font_size',array(
		'label'	=> __('Button Font Size','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'vw-life-coach' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_life_coach_button_settings',
	));

	$wp_customize->add_setting( 'vw_life_coach_button_border_radius', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_life_coach_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-life-coach' ),
		'section'     => 'vw_life_coach_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_life_coach_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_button_padding_top_bottom',array(
		'label'	=> esc_html__('Padding Top Bottom','vw-life-coach'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'vw-life-coach' ),
        ),
		'section' => 'vw_life_coach_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting('vw_life_coach_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_button_padding_left_right',array(
		'label'	=> esc_html__('Padding Left Right','vw-life-coach'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'vw-life-coach' ),
        ),
		'section' => 'vw_life_coach_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting('vw_life_coach_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'vw-life-coach' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_life_coach_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('vw_life_coach_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','vw-life-coach'),
		'choices' => array(
            'Uppercase' => __('Uppercase','vw-life-coach'),
            'Capitalize' => __('Capitalize','vw-life-coach'),
            'Lowercase' => __('Lowercase','vw-life-coach'),
        ),
		'section'=> 'vw_life_coach_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_life_coach_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_life_coach_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_life_coach_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','vw-life-coach' ),
		'section' => 'vw_life_coach_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_life_coach_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_life_coach_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'vw_life_coach_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_life_coach_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','vw-life-coach' ),
		'section'     => 'vw_life_coach_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'vw_life_coach_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'vw_life_coach_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('vw_life_coach_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_single_blog_settings',
		'setting'	=> 'vw_life_coach_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_life_coach_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','vw-life-coach' ),
	   'section' => 'vw_life_coach_single_blog_settings'
	)));

	$wp_customize->add_setting('vw_life_coach_single_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_single_author_icon',array(
		'label'	=> __('Add Author Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_single_blog_settings',
		'setting'	=> 'vw_life_coach_single_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_life_coach_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','vw-life-coach' ),
	    'section' => 'vw_life_coach_single_blog_settings'
	)));

   	$wp_customize->add_setting('vw_life_coach_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_single_blog_settings',
		'setting'	=> 'vw_life_coach_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_life_coach_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','vw-life-coach' ),
	    'section' => 'vw_life_coach_single_blog_settings'
	)));

	$wp_customize->add_setting('vw_life_coach_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_single_time_icon',array(
		'label'	=> __('Add Time Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_single_blog_settings',
		'setting'	=> 'vw_life_coach_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_life_coach_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_time',array(
	    'label' => esc_html__( 'Show / Hide Time','vw-life-coach' ),
	    'section' => 'vw_life_coach_single_blog_settings'
	)));

	$wp_customize->add_setting( 'vw_life_coach_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','vw-life-coach' ),
		'section' => 'vw_life_coach_single_blog_settings'
    )));

     // Single Posts Category
  	$wp_customize->add_setting( 'vw_life_coach_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
  	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','vw-life-coach' ),
		'section' => 'vw_life_coach_single_blog_settings'
    )));

	$wp_customize->add_setting( 'vw_life_coach_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','vw-life-coach' ),
		'section' => 'vw_life_coach_single_blog_settings'
    )));

	$wp_customize->add_setting('vw_life_coach_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-life-coach'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-life-coach'),
		'section'=> 'vw_life_coach_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_life_coach_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	));
	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_blog_post_navigation_show_hide', array(
		  'label' => esc_html__( 'Show / Hide Post Navigation','vw-life-coach' ),
		  'section' => 'vw_life_coach_single_blog_settings'
	)));

	//navigation text
	$wp_customize->add_setting('vw_life_coach_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-life-coach'),
		'input_attrs' => array(
    'placeholder' => __( 'PREVIOUS', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_single_blog_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_life_coach_single_blog_comment_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_life_coach_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_single_blog_comment_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_life_coach_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_single_blog_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_life_coach_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','vw-life-coach'),
		'description'	=> __('Enter a value in %. Example:50%','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_single_blog_settings',
		'type'=> 'text'
	));

    // Grid layout setting
	$wp_customize->add_section( 'vw_life_coach_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('vw_life_coach_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_grid_layout_settings',
		'setting'	=> 'vw_life_coach_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_life_coach_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','vw-life-coach' ),
        'section' => 'vw_life_coach_grid_layout_settings'
    )));

	$wp_customize->add_setting('vw_life_coach_grid_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_grid_author_icon',array(
		'label'	=> __('Add Author Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_grid_layout_settings',
		'setting'	=> 'vw_life_coach_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_life_coach_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-life-coach' ),
		'section' => 'vw_life_coach_grid_layout_settings'
    )));

   	$wp_customize->add_setting('vw_life_coach_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_grid_layout_settings',
		'setting'	=> 'vw_life_coach_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_life_coach_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-life-coach' ),
		'section' => 'vw_life_coach_grid_layout_settings'
    )));

 	$wp_customize->add_setting('vw_life_coach_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-life-coach'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-life-coach'),
		'section'=> 'vw_life_coach_grid_layout_settings',
		'type'=> 'text'
	));  

  	$wp_customize->add_setting('vw_life_coach_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','vw-life-coach'),
	    'section' => 'vw_life_coach_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','vw-life-coach'),
	      	'Without Blocks' => __('Without Blocks','vw-life-coach')
	      ),
	) );

	$wp_customize->add_setting('vw_life_coach_grid_button_text',array(
		'default'=> esc_html__('Read More','vw-life-coach'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_grid_layout_settings',
		'type'=> 'text'
	));

	//Others Settings
	$wp_customize->add_panel( 'vw_life_coach_others_panel', array(
		'title' => esc_html__( 'Others Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_panel_id',
		'priority' => 20,
	));

	// Layout
	$wp_customize->add_section( 'vw_life_coach_left_right', array(
    	'title' => esc_html__( 'General Settings', 'vw-life-coach' ),
		'panel' => 'vw_life_coach_others_panel'
	) );

	$wp_customize->add_setting('vw_life_coach_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Life_Coach_Image_Radio_Control($wp_customize, 'vw_life_coach_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','vw-life-coach'),
        'description' => esc_html__('Here you can change the width layout of Website.','vw-life-coach'),
        'section' => 'vw_life_coach_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('vw_life_coach_page_layout',array(
        'default' => 'One Column',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','vw-life-coach'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','vw-life-coach'),
        'section' => 'vw_life_coach_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','vw-life-coach'),
            'Right Sidebar' => esc_html__('Right Sidebar','vw-life-coach'),
            'One Column' => esc_html__('One Column','vw-life-coach')
        ),
	) );

   	$wp_customize->add_setting( 'vw_life_coach_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','vw-life-coach' ),
		'section' => 'vw_life_coach_left_right'
    )));

    //Wow Animation
	$wp_customize->add_setting( 'vw_life_coach_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_animation',array(
        'label' => esc_html__( 'Show / Hide Animations','vw-life-coach' ),
        'description' => __('Here you can disable overall site animation effect','vw-life-coach'),
        'section' => 'vw_life_coach_left_right'
    )));

    $wp_customize->add_setting('vw_life_coach_reset_all_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field',
   	));
   	$wp_customize->add_control(new VW_Life_Coach_Reset_Custom_Control($wp_customize, 'vw_life_coach_reset_all_settings',array(
      'type' => 'reset_control',
      'label' => __('Reset All Settings', 'vw-life-coach'),
      'description' => 'vw_life_coach_reset_all_settings',
      'section' => 'vw_life_coach_left_right'
   	)));

    //Pre-Loader
	$wp_customize->add_setting( 'vw_life_coach_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','vw-life-coach' ),
        'section' => 'vw_life_coach_left_right'
    )));

	$wp_customize->add_setting('vw_life_coach_preloader_bg_color', array(
		'default'           => '#ea430f',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_left_right',
	)));

	$wp_customize->add_setting('vw_life_coach_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_left_right',
	)));

	$wp_customize->add_setting('vw_life_coach_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_life_coach_preloader_bg_img',array(
        'label' => __('Preloader Background Image','vw-life-coach'),
        'section' => 'vw_life_coach_left_right'
	)));

    //404 Page Setting
	$wp_customize->add_section('vw_life_coach_404_page',array(
		'title'	=> __('404 Page Settings','vw-life-coach'),
		'panel' => 'vw_life_coach_others_panel',
	));

	$wp_customize->add_setting('vw_life_coach_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_life_coach_404_page_title',array(
		'label'	=> __('Add Title','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_life_coach_404_page_content',array(
		'label'	=> __('Add Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( 'GO BACK', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_404_page',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('vw_life_coach_no_results_page',array(
		'title'	=> __('No Results Page Settings','vw-life-coach'),
		'panel' => 'vw_life_coach_others_panel',
	));	

	$wp_customize->add_setting('vw_life_coach_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_life_coach_no_results_page_title',array(
		'label'	=> __('Add Title','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_life_coach_no_results_page_content',array(
		'label'	=> __('Add Text','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('vw_life_coach_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','vw-life-coach'),
		'panel' => 'vw_life_coach_others_panel',
	));

	$wp_customize->add_setting('vw_life_coach_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_social_icon_padding',array(
		'label'	=> __('Icon Padding','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_social_icon_width',array(
		'label'	=> __('Icon Width','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_social_icon_height',array(
		'label'	=> __('Icon Height','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_social_icon_settings',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_life_coach_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','vw-life-coach'),
		'panel' => 'vw_life_coach_others_panel',
	));

    $wp_customize->add_setting( 'vw_life_coach_resp_slider_hide_show',array(
      	'default' => 1,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','vw-life-coach' ),
      	'section' => 'vw_life_coach_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_life_coach_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','vw-life-coach' ),
      	'section' => 'vw_life_coach_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_life_coach_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-life-coach' ),
      	'section' => 'vw_life_coach_responsive_media'
    )));

    $wp_customize->add_setting('vw_life_coach_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_life_coach_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'vw-life-coach'),
		'section'  => 'vw_life_coach_responsive_media',
	)));

    $wp_customize->add_setting('vw_life_coach_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_responsive_media',
		'setting'	=> 'vw_life_coach_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_life_coach_res_close_menus_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Life_Coach_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_life_coach_res_close_menus_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-life-coach'),
		'transport' => 'refresh',
		'section'	=> 'vw_life_coach_responsive_media',
		'setting'	=> 'vw_life_coach_res_close_menus_icon',
		'type'		=> 'icon'
	)));

    //Woocommerce settings
	$wp_customize->add_section('vw_life_coach_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'vw-life-coach'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

  	//Shop Page Featured Image
	$wp_customize->add_setting( 'vw_life_coach_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_life_coach_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','vw-life-coach' ),
		'section'     => 'vw_life_coach_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_life_coach_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_life_coach_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_life_coach_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','vw-life-coach' ),
		'section'     => 'vw_life_coach_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_life_coach_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_woocommerce_shop_page_sidebar', ) );

    //Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_life_coach_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','vw-life-coach' ),
		'section' => 'vw_life_coach_woocommerce_section'
    )));

    $wp_customize->add_setting('vw_life_coach_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','vw-life-coach'),
        'section' => 'vw_life_coach_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-life-coach'),
            'Right Sidebar' => __('Right Sidebar','vw-life-coach'),
        ),
	) );

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_life_coach_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'vw_life_coach_customize_partial_vw_life_coach_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_life_coach_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_life_coach_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','vw-life-coach' ),
		'section' => 'vw_life_coach_woocommerce_section'
    )));

    $wp_customize->add_setting('vw_life_coach_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','vw-life-coach'),
        'section' => 'vw_life_coach_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-life-coach'),
            'Right Sidebar' => __('Right Sidebar','vw-life-coach'),
        ),
	) ); 

	$wp_customize->add_setting('vw_life_coach_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_woocommerce_section',
		'type'=> 'text'
	));

	//Products Sale Badge
	$wp_customize->add_setting('vw_life_coach_woocommerce_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'vw_life_coach_sanitize_choices'
	));
	$wp_customize->add_control('vw_life_coach_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','vw-life-coach'),
        'section' => 'vw_life_coach_woocommerce_section',
        'choices' => array(
            'left' => __('Left','vw-life-coach'),
            'right' => __('Right','vw-life-coach'),
        ),
	) );

	$wp_customize->add_setting('vw_life_coach_woocommerce_sale_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_woocommerce_sale_padding_top_bottom',array(
		'label'	=> __('Sale Padding Top Bottom','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_life_coach_woocommerce_sale_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_life_coach_woocommerce_sale_padding_left_right',array(
		'label'	=> __('Sale Padding Left Right','vw-life-coach'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-life-coach'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-life-coach' ),
        ),
		'section'=> 'vw_life_coach_woocommerce_section',
		'type'=> 'text'
	));

	// Related Product
	$wp_customize->add_setting( 'vw_life_coach_related_product_show_hide',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_life_coach_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Life_Coach_Toggle_Switch_Custom_Control( $wp_customize, 'vw_life_coach_related_product_show_hide',array(
	    'label' => esc_html__( 'Show / Hide Related Product','vw-life-coach' ),
	    'section' => 'vw_life_coach_woocommerce_section'
	)));

    // Has to be at the top
	$wp_customize->register_panel_type( 'VW_Life_Coach_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'VW_Life_Coach_WP_Customize_Section' );
}

add_action( 'customize_register', 'vw_life_coach_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class VW_Life_Coach_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'vw_life_coach_panel';
	    public function json() {
			$array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
			$array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
			$array['content'] = $this->get_content();
			$array['active'] = $this->active();
			$array['instanceNumber'] = $this->instance_number;
			return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class VW_Life_Coach_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'vw_life_coach_section';
	    public function json() {
			$array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
			$array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
			$array['content'] = $this->get_content();
			$array['active'] = $this->active();
			$array['instanceNumber'] = $this->instance_number;

			if ( $this->panel ) {
			$array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
			} else {
			$array['customizeAction'] = 'Customizing';
			}
			return $array;
    	}
  	}
}

// Enqueue our scripts and styles
function vw_life_coach_customize_controls_scripts() {
	wp_enqueue_script( 'vw-life-coach-customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'vw_life_coach_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Life_Coach_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Life_Coach_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new VW_Life_Coach_Customize_Section_Pro( $manager,'vw_life_coach_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW LIFE COACH PRO', 'vw-life-coach' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-life-coach' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/life-coach-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new VW_Life_Coach_Customize_Section_Pro($manager,'vw_life_coach_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-life-coach' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-life-coach' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-vw-life-coach/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-life-coach-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-life-coach-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );

		wp_localize_script(
		'vw-life-coach-customize-controls',
		'vw_life_coach_customizer_params',
		array(
			'ajaxurl' =>	admin_url( 'admin-ajax.php' )
		));
	}
}

// Doing this customizer thang!
VW_Life_Coach_Customize::get_instance();